@@ -12,7 +12,7 @@ class AESCipher(object):
         self.key = hashlib.sha3_256(try_utf8e(key)).digest()
 
     def encrypt(self, raw: str_or_bytes) -> str:
-        raw = _pad(raw)
+        raw = try_utf8e(self.__pad(raw))
         iv = Random.new().read(AES.block_size)
         cipher = AES.new(self.key, AES.MODE_CBC, iv)
         return b64e(iv + cipher.encrypt(raw))
@@ -21,22 +21,22 @@ class AESCipher(object):
         enc = b64d(enc)
         iv = enc[:AES.block_size]
         cipher = AES.new(self.key, AES.MODE_CBC, iv)
-        return _unpad(cipher.decrypt(enc[AES.block_size:]))
+        return try_utf8d(self.__unpad(cipher.decrypt(enc[AES.block_size:])))
 
+    @staticmethod
+    def __pad(s: str_or_bytes) -> str_or_bytes:
+        gap = AES.block_size - len(s) % AES.block_size
+        char = ""
+        if isinstance(s, bytes):
+            char = bytes(bytearray.fromhex(format(gap, "x").zfill(2)))
+        else:
+            char = chr(gap)
+        s = s + char * gap
+        return s
 
-def _pad(s: str_or_bytes) -> bytes:
-    gap = AES.block_size - len(s) % AES.block_size
-    char = ""
-    if isinstance(s, bytes):
-        char = bytes(bytearray.fromhex(format(gap, "x").zfill(2)))
-    else:
-        char = chr(gap)
-    s = s + char * gap
-    return try_utf8e(s)
-
-
-def _unpad(s: str_or_bytes) -> str_or_bytes:
-    s = s[:-ord(s[len(s)-1:])]
-    return try_utf8d(s)
+    @staticmethod
+    def __unpad(s: str_or_bytes) -> str_or_bytes:
+        s = s[:-ord(s[len(s)-1:])]
+        return s
 
 
